@@ -14,9 +14,6 @@ class JSONLoader(Loader):
         def loader(data: Union[str, dict], _: FileInfo) -> Optional[Dict]:
             data_as_dict = json.loads(data) if isinstance(data, str) else data
             typ = data_as_dict.pop('@type', None)
-            # TODO: Remove this when https://github.com/linkml/issues/364 gets fixed
-            if not typ:
-                typ = data_as_dict.pop('@type', None)
             if typ and typ != target_class.__name__:
                 # TODO: connect this up with the logging facility or warning?
                 print(f"Warning: input type mismatch. Expected: {target_class.__name__}, Actual: {typ}")
